<?php
namespace ElementorFastCarousel;

/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.0.0
 */
class Plugin {

	/**
	 * Instance
	 *
	 * @since 1.0.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function widget_scripts() {

		// Load WP jQuery if not included
		wp_enqueue_script('jquery');
		wp_enqueue_script('jquery-masonry');


		// Load main js script
		wp_enqueue_script( 'woocommerceproductsrevolutiondisplay-frontend', plugins_url( '/assets/js/woocommerce-products-revolution-display.js', __FILE__ ), [ 'jquery' ], false, true );

		// Main
		wp_register_style( 'woocommerceproductsrevolutiondisplay-vc-main-style', plugins_url( '/assets/css/style.css', __FILE__ ) );
		wp_register_style( 'fonts-vc',  plugins_url( 'assets/css/fonts.css', __FILE__ ));
		wp_enqueue_style( 'woocommerceproductsrevolutiondisplay-vc-main-style' );

		// Carousel
		wp_register_style( 'owlcarousel',  plugins_url( 'assets/css/owl.carousel.css', __FILE__ ) );
		wp_register_style( 'owltheme',  plugins_url( 'assets/css/owl.theme.css', __FILE__ ) );
		wp_register_script( 'owlcarousel',  plugins_url( 'assets/js/vendor/owl.carousel.js' , __FILE__ ), [ 'jquery' ], false, true );

		// PRETTYPHOTO
		wp_register_script('prettyPhoto', plugins_url( 'assets/js/vendor/jquery.prettyPhoto.js', __FILE__ ), [ 'jquery' ], false, true );
		wp_register_style( 'prettyPhoto',  plugins_url( 'assets/css/prettyPhoto.css', __FILE__ ) );

		// MAGNIFIC POPUP
		wp_register_script('magnific-popup', plugins_url( 'assets/js/vendor/jquery.magnific-popup.js', __FILE__ ), [ 'jquery' ], false, true );
		wp_register_style( 'magnific-popup',  plugins_url( 'assets/css/magnific-popup.css', __FILE__  ) );

		// LIGHT GALLERY
		wp_register_style( 'lightgallery',  plugins_url( 'assets/css/lightGallery.css', __FILE__ ) );
		wp_register_script( 'lightgallery',  plugins_url( 'assets/js/vendor/lightGallery.min.js' , __FILE__ ), [ 'jquery' ], false, true );

		// PHOTOSWIPE
		wp_register_style( 'photoswipe',  plugins_url( 'assets/css/photoswipe.css', __FILE__ ) );
		wp_register_style( 'photoswipe-default-skin',  plugins_url( 'assets/css/default-skin.css', __FILE__ ) );
		wp_register_script( 'photoswipe',  plugins_url( 'assets/js/vendor/photoswipe.min.js' , __FILE__ ), [ 'jquery' ], false, true );
		wp_register_script( 'photoswipe-ui-default-js',  plugins_url( 'assets/js/vendor/photoswipe-ui-default.min.js' , __FILE__ ), [ 'jquery' ], false, true );
		wp_register_script( 'photoswipe-general-js',  plugins_url( 'assets/js/vendor/photoswipe-general.js' , __FILE__ ), [ 'jquery' ], false, true );

		// ANIMATE
		wp_register_style( 'animations',  plugins_url( 'assets/css/animations.min.css', __FILE__ ) );
		wp_register_script( 'appear',  plugins_url( 'assets/js/vendor/appear.min.js' , __FILE__ ), [ 'jquery' ], false, true );
		wp_register_script( 'animate',  plugins_url( 'assets/js/vendor/animations.min.js' , __FILE__ ), [ 'jquery' ], false, true );

		if(\Elementor\Plugin::$instance->preview->is_preview_mode()) {
			wp_enqueue_style( 'fonts-vc' );
			wp_enqueue_style( 'owlcarousel' );
			wp_enqueue_style( 'owltheme' );
			wp_enqueue_script( 'owlcarousel' );
			wp_enqueue_style( 'prettyPhoto' );
			wp_enqueue_script( 'prettyPhoto' );
			wp_enqueue_style( 'magnific-popup' );
			wp_enqueue_script( 'magnific-popup' );
			wp_enqueue_style( 'lightgallery' );
			wp_enqueue_script( 'lightgallery' );
			wp_enqueue_style( 'photoswipe' );
			wp_enqueue_style( 'photoswipe-default-skin' );
			wp_enqueue_script( 'photoswipe' );
			wp_enqueue_script( 'photoswipe-ui-default-js' );
			wp_enqueue_script( 'photoswipe-general-js' );
			wp_enqueue_style( 'animations' );
			wp_enqueue_script( 'appear' );
			wp_enqueue_script( 'animate' );
			wp_enqueue_style( 'elementor-icons' );
			wp_enqueue_style( 'font-awesome' );
		}
	}

	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.0.0
	 * @access private
	 */
	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/Showcase/products-display.php' );
		require_once( __DIR__ . '/widgets/widgets-help-functions.php' );
	}

	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\WooCommerce_Products_Revolution_Display() );
	}

	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.0.0
	 * @access public
	 */
	public function __construct() {

		// Register widget scripts
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'register_widgets' ] );
	}
}

// Instantiate Plugin Class
Plugin::instance();
